// src/flexstore/FlexMachine.js
import { createSlice } from "@reduxjs/toolkit";
var FlexintialConfiguration = [{
  data: {},
  storageType: "local"
}];
var initialvalue = (data) => {
  return (data || []).map((item) => ({ ...item }));
};
var resultObject = initialvalue(FlexintialConfiguration).reduce(
  (accumulator, currentObject) => {
    return { ...accumulator, ...currentObject };
  },
  {}
);
var saveStateToStorage = (state, storageType) => {
  switch (storageType) {
    case "local":
      localStorage.setItem("FlexState", JSON.stringify(state));
      break;
    case "session":
      sessionStorage.setItem("FlexState", JSON.stringify(state));
      break;
    default:
      break;
  }
};
var storedState = JSON.parse(localStorage.getItem("FlexState")) || JSON.parse(sessionStorage.getItem("FlexState"));
if (!storedState) {
  saveStateToStorage(resultObject, FlexintialConfiguration.storageType);
}
var initialState = storedState || resultObject;
var reducers = {};
for (let key in initialState) {
  const setKey = `${key.charAt(0).toUpperCase() + key.slice(1)}`;
  reducers[setKey] = (state, action) => {
    state[key] = action.payload;
    saveStateToStorage(state, FlexintialConfiguration[0].storageType);
  };
}
var iqSlice = createSlice({
  name: "iqSlice",
  initialState,
  reducers
});
var htboxSelector = iqSlice.actions;
var FlexMachine_default = iqSlice.reducer;

// src/flexstore/flexService.js
import { useDispatch, useSelector } from "react-redux";
import axios from "axios";
var useFlexService = () => {
  const dispatch = useDispatch();
  const iqSliceState = useSelector((state) => state.iqSlice);
  function FlexSender(storeName, args) {
    const dispatchHandler = htboxSelector["Data"];
    try {
      return dispatch(dispatchHandler({ ...iqSliceState.data, [storeName]: args }));
    } catch (error) {
      console.error("An error occurred while dispatching the action:", error);
    }
  }
  function FlexDetector(args) {
    return iqSliceState.data[args];
  }
  async function FlexApi({
    method,
    url,
    payload: data = null,
    contentType = "application/json",
    onUploadProgress = null,
    onDownloadProgress = null,
    flexstore
  }) {
    try {
      let loadingStatus = "Loading...";
      let loadedPercentage = 0;
      const config = {
        headers: {
          "Content-Type": contentType
        },
        onUploadProgress,
        // Pass the provided onUploadProgress callback
        onDownloadProgress
        // Pass the provided onDownloadProgress callback
      };
      let response;
      if (method === "GET") {
        if (data) {
          response = await axios.get(url, { ...config, data });
        } else {
          response = await axios.get(url, config);
        }
      } else if (method === "POST") {
        response = await axios.post(url, data, config);
      } else if (method === "PUT") {
        response = await axios.put(url, data, config);
      } else if (method === "DELETE") {
        response = await axios.delete(url, config);
      }
      loadingStatus = "Loading completed.";
      if (flexstore == null ? void 0 : flexstore.storeaccess) {
        FlexSender(flexstore == null ? void 0 : flexstore.statename, response.data);
      }
      return {
        data: response.data,
        loadingStatus,
        loadedPercentage,
        status: response.status
      };
    } catch (error) {
      console.error("Error:", error.message);
      return {
        data: null,
        loadingStatus: "Error occurred.",
        loadedPercentage: 0,
        error: error.message,
        status: error.response ? error.response.status : 500
      };
    }
  }
  return {
    FlexSender,
    FlexDetector,
    FlexApi
  };
};

// src/flexstore/FlexConfig.jsx
import React from "react";
import { Provider } from "react-redux";
import { configureStore } from "@reduxjs/toolkit";
var FlexStore = configureStore({
  reducer: {
    iqSlice: FlexMachine_default
    // Add other reducers here if needed
  }
});
var FlexProvider = (props) => {
  const { element } = props;
  return /* @__PURE__ */ React.createElement(Provider, { store: FlexStore }, element);
};
export {
  FlexProvider,
  FlexintialConfiguration,
  htboxSelector,
  initialvalue,
  useFlexService
};
